"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const testing_1 = require("@nestjs/testing");
const slack_module_1 = require("../slack.module");
const slack_service_1 = require("../slack.service");
const jest_mock_web_client_1 = require("@slack-wrench/jest-mock-web-client");
const slack_block_builder_1 = require("slack-block-builder");
describe('SlackService', () => {
    let service;
    let output;
    const createApp = (options) => {
        return testing_1.Test.createTestingModule({
            imports: [slack_module_1.SlackModule.forRoot(options)],
        }).compile();
    };
    it('should be defined', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const app = yield createApp();
        expect(app.get(slack_service_1.SlackService)).toBeDefined();
    }));
    describe('helpers', () => {
        let service;
        beforeEach(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const app = yield createApp();
            service = app.get(slack_service_1.SlackService);
            service.postMessage = jest.fn();
        }));
        describe('sendText', () => {
            it('should forward to sendMessage', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
                yield service.sendText('hello world');
                expect(service.postMessage).toHaveBeenCalledWith({
                    text: 'hello world',
                });
            }));
        });
        describe('sendBlocks', () => {
            it('should forward to sendMessage', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
                const blocks = slack_block_builder_1.BlockCollection(slack_block_builder_1.Blocks.Section({ text: 'hello-world' }));
                yield service.sendBlocks(blocks);
                expect(service.postMessage).toHaveBeenCalledWith({ blocks });
            }));
        });
    });
    describe('types', () => {
        describe('api', () => {
            beforeEach(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
                output = jest.fn();
                const app = yield createApp({
                    type: 'api',
                    defaultChannel: 'my-channel',
                    apiOptions: { token: 'my-token' },
                });
                service = app.get(slack_service_1.SlackService);
            }));
            it('should send requests to API', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
                yield service.postMessage({ text: 'hello-world' });
                expect(jest_mock_web_client_1.MockedWebClient.mock.instances[0].chat.postMessage).toHaveBeenCalledWith({
                    channel: 'my-channel',
                    text: 'hello-world',
                });
            }));
        });
        describe('stdout', () => {
            beforeEach(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
                output = jest.fn();
                const app = yield createApp({ output });
                service = app.get(slack_service_1.SlackService);
            }));
            it('should output requests to stdout', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
                const request = {
                    text: 'hello-world',
                    channel: 'hello-world',
                };
                yield service.postMessage(request);
                expect(output).toHaveBeenCalledWith(request);
            }));
        });
        describe('stackdriver', () => {
            beforeEach(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
                output = jest.fn();
                const app = yield createApp({ type: 'stackdriver', output });
                service = app.get(slack_service_1.SlackService);
            }));
            it('should output requests to stdout with structured logs', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
                const request = {
                    text: 'hello-world',
                    channel: 'hello-world',
                };
                yield service.postMessage(request);
                expect(output).toHaveBeenCalledWith({
                    message: request,
                    severity: 'NOTICE',
                    'logging.googleapis.com/labels': { type: 'nestjs-slack' },
                    'logging.googleapis.com/operation': {
                        producer: 'github.com/bjerkio/nestjs-slack',
                    },
                });
            }));
        });
    });
});
