"use strict";
var SlackModule_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.SlackModule = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const constants_1 = require("./constants");
const slack_service_1 = require("./slack.service");
const utils_1 = require("./utils");
let SlackModule = SlackModule_1 = class SlackModule {
    static forRoot(opts) {
        const options = Object.assign({ type: 'stdout', output: (out) => process.stdout.write(JSON.stringify(out)) }, opts);
        const providers = [
            {
                provide: constants_1.SLACK_MODULE_OPTIONS,
                useValue: options,
            },
            this.createAsyncWebClient(options),
        ];
        return {
            global: options.isGlobal,
            module: SlackModule_1,
            providers,
            exports: providers,
        };
    }
    static createAsyncWebClient({ type }) {
        if (type !== 'api') {
            return {
                provide: constants_1.SLACK_WEB_CLIENT,
                useValue: null,
            };
        }
        return {
            provide: constants_1.SLACK_WEB_CLIENT,
            inject: [constants_1.SLACK_MODULE_OPTIONS],
            useFactory: (opts) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                utils_1.invariant(opts.apiOptions, 'You must provide `apiOptions` when using the api type.');
                const { WebClient } = yield Promise.resolve().then(() => require('@slack/web-api'));
                return new WebClient(opts.apiOptions.token, opts.apiOptions.clientOptions);
            }),
        };
    }
};
SlackModule = SlackModule_1 = tslib_1.__decorate([
    common_1.Module({
        providers: [slack_service_1.SlackService],
        exports: [slack_service_1.SlackService],
    })
], SlackModule);
exports.SlackModule = SlackModule;
